
function [x,b_mean,b_rms,b_emit,b_twiss,weight] = beam_statistics(phasespace,gammag)
    % x       centered phase space (long, hor, ver, p_long, p_hor, p_ver)
    % b_mean  mean values of incoming coordinates                     
    % b_rms   rms values of centered coordinates
    % b_emit  emittance values for x-xp, y-yp and s-de/e space
    % b_twiss twiss parameters for x-xp, y-yp and s-de/e space 
    %         (alpha(long,hor,ver),beta(...),gamma(...)) 
    % T. Limberg 27.4.2004

    % normalize charge distribution to one
    sum_q  = sum( phasespace(:,7) );
    weight = phasespace(:,7)./sum_q;

    x           = zeros(length(phasespace),6);
    b_rms       = zeros(1,6);
    b_mean      = zeros(1,6);
    b_emit      = zeros(1,5);
    b_emit_real = zeros(1,5);
    alpha       = zeros(1,5);
    beta        = zeros(1,5);
    gamma       = zeros(1,5);
    % emittance etc 
    for i=1:6
        b_mean(i) = sum(phasespace(:,i).*weight);
        x(:,i)    = phasespace(:,i) - b_mean(i);
        b_rms(i)  = sqrt(sum(x(:,i).^2 .*weight));
    end
    for i=1:2:5
        b_emit(i) = gammag * sqrt( b_rms(i)^2 * b_rms(i+1)^2  - ...
            (sum(x(:,i) .* x(:,i+1) .* weight)^2 ) );
        % Twiss parameters
        b_emit_real(i) = b_emit(i) / gammag;
        if(b_emit_real(i) == 0)
            beta(i)         = 0;
            gamma(i)        = 0;
            alpha(i) = 0;
        else   
            beta(i)         = b_rms(i)^2    / b_emit_real(i);
            gamma(i)        = b_rms(i+1)^2  / b_emit_real(i);
            % sign alpha
            alpha_sign = sign( polyfit(phasespace(:,i), phasespace(:,i+1), 1) );
            alpha(i)   = sqrt( beta(i)*gamma(i) - 1)*(-alpha_sign(1) );
        end
    end
    b_twiss = [alpha;beta;gamma];
end