function [yfit,dy,c,limits] = poli_approx(x,y,q,K)
    % fits y(x) to a polinominal of order K and hands the fitted curve yfit and 
    % the deviations dy back.
    % TL 3_2006 after some MD mathcad script

    % check stuff
    K=round(K);
    if K <= 1
       disp('poli_approx: K must be an integer >1')
       return
    end

    if length(x) < 10
       disp('poli_approx: N must be at least 10')
       return
    end
    
    weight = q;
    if length(q) ~= length(x)
        weight = ones(size(x));
    end

    % put x into an intervall -1 to +1
    a = min(x);
    b = max(x);
    limits = [a b];
    if a==b
        disp('poli_approx warning: all particles in slice have same longitudinal position')
        yfit = mean(y) * ones(length(y),1);
        dy   = y - mean(y);
        c    = 1;
        return
    end
    z = -1 + 2 / (b-a)*(x-a);

    % apply weight function
    by = y.*weight;

    % set up polinominal matrix
    k = 0:K;

    % pre-set A
    A = zeros(length(z),K+1);
    for n=1:length(z)
        A(n,:) = weight(n) * z(n).^k;
    end
    if size(by) ~= length(by)
        by = by';
    end
    c    = (A'*A) ^ (-1) * (A'*by);
    yfit = A * c;
    dy   = yfit - y;
end
