function [ data ] = psv_calc_slice( data )
    if nargin ~= 1; return; end;
    % clear slices
    data.ps(data.my_axes).slices = [ ] ;

    % unpack centered phase space and energy and bin-id
    x       = data.ps(data.my_axes).b_stat.x;
    gammag  = data.ps(data.my_axes).gamma;
    bin     = data.ps(data.my_axes).bin;
    weight  = data.ps(data.my_axes).b_stat.weight;

    % loop over bunch slices
    for i_slice = 1:length(data.ps(data.my_axes).b_stat.grid)
        % find indices in structure
        ind = find(bin==i_slice);
        % for more than 10 particles in the slice, the valid flag is set to true
        if length(ind) >10
            data.ps(data.my_axes).slices(i_slice).valid = 1;
        else
            data.ps(data.my_axes).slices(i_slice).valid = 0;
        end
        
        % extract slice population
        if data.ps(data.my_axes).slices(i_slice).valid == 1
            slice_ps     = x(ind,:);
            slice_weight = weight(ind); 
            % calculate slice statistical moments and optics
            [dummy,b_mean,b_rms,b_emit,b_twiss, sum_q] =...
                    beam_statistics([slice_ps slice_weight], gammag);
            
            % store in structure
            data.ps(data.my_axes).slices(i_slice).b_stat.b_mean  = b_mean;
            data.ps(data.my_axes).slices(i_slice).b_stat.b_rms   = b_rms;
            data.ps(data.my_axes).slices(i_slice).b_stat.b_emit  = b_emit;
            data.ps(data.my_axes).slices(i_slice).b_stat.b_twiss = b_twiss;
            data.ps(data.my_axes).slices(i_slice).b_stat.b_sumq =  sum_q;
            
            % do MD's analysis for longitudinal phase space
            [e_fit,de] = poli_approx( slice_ps(:,5), slice_ps(:,6), 0, 3);
            data.ps(data.my_axes).slices(i_slice).b_stat.pfit.e_rms = std(de);
        end
    end
end