% Initialize 
function [ data ] = psv_initialize( data, handles)
     if nargin ~= 2; return; end;
    data.my_axes = 1;

    data.psv_hnames.message_log_handle = handles.text_message; % psv_message needs handle
    psv_message(data, 'Initializing',0);
    % structure for phase space
    data.ps = struct();
    data.ps(2) = data.ps;

    % rf initial values
    data.psv_rf.nu = 1.3e9;
    data.psv_rf.n = 3;

    % structure for defaults
    data.psv_defaults = struct();
    data.psv_defaults(1).path = '';
    data.psv_defaults(2).path = '';
    
    data.psv_options = struct();

    % make structure for handle names
    data.psv_hnames.RMS_handles     = [handles.text_RMS_11 handles.text_RMS_12 ; handles.text_RMS_21 handles.text_RMS_22];
    data.psv_hnames.emit_handles    = [handles.text_emit_1 handles.text_emit_2]; 
    data.psv_hnames.twiss_handles   = [handles.text_twiss_1 handles.text_twiss_2];
    data.psv_hnames.popup_handles   = [handles.popupmenu_11 handles.popupmenu_12 ; handles.popupmenu_21 handles.popupmenu_22];
    data.psv_hnames.axes_handles    = [handles.axes1 handles.axes2];
    data.psv_hnames.dir_handles     = [handles.slider_files_1 handles.slider_files_2 ; ...
                                handles.edit_dir_1 handles.edit_dir_2 ;...
                                handles.text_file_1 handles.text_file_2 ;...
                                handles.pushbutton_movie_1  handles.pushbutton_movie_2 ; ...
                                handles.pushbutton_save_movie_1 handles.pushbutton_save_movie_2 ];
    data.psv_hnames.slice_handles   = [handles.slider_slice_1 handles.slider_slice_2 ; ...
                                handles.edit_slice_1 handles.edit_slice_2 ;...
                                handles.edit_slicenr_1 handles.edit_slicenr_2 ;...
                                handles.text_slice_1 handles.text_slice_2 ;...
                                handles.text_slicenr_1 handles.text_slicenr_2 ;...
                                handles.togglebutton_slice_1  handles.togglebutton_slice_2];
    data.psv_hnames.mesh_handles     = [handles.checkboxmesh_1 handles.checkboxmesh_2];
    data.psv_hnames.square_handles   = [handles.checkboxsquare_1 handles.checkboxsquare_2];
    data.psv_hnames.menus = [ handles.File_menu_save_as handles.Edit_menu_RF_Chirp ...
        handles.Edit_menu_Twiss_Parameters handles.axes_in_seperate_window ...
        handles.Plot_Menue_Mesh handles.Plot_Menue_Sum handles.Options_Menue_Plot_Mesh ...
        handles.Options_Menue_Plot_Sum handles.Options_Menue_Plot_Plot ];
    data.psv_hnames.menus = [ handles.File_menu_save_as handles.Edit_menu_RF_Chirp ...
        handles.Edit_menu_Twiss_Parameters handles.axes_in_seperate_window ...
        handles.Plot_Menue_Sum ];
    data.psv_hnames.meshplotMenu     = handles.Plot_Menue_Mesh;
    data.psv_hnames.poltminchi       = handles.poltminchi;

    data.psv_hnames.psv_gui          = handles.psv_gui;
    data.psv_hnames.getPopupEntries  = @getPopupEntries; % will be used in psv_set_ui_visibility()
    data.psv_hnames.isSliceable      = @isSliceable;     % and ps_viewer>setVHbyPopupMenu()

    % set axis to longitudinal phase space for first plots
    data.ps(1).hor_axis = 5;
    data.ps(1).ver_axis = 6;
    data.ps(2).hor_axis = data.ps(1).hor_axis;
    data.ps(2).ver_axis = data.ps(1).ver_axis;
    set(data.psv_hnames.popup_handles(:,2), 'Value', data.ps(1).hor_axis);
    set(data.psv_hnames.popup_handles(:,1), 'Value', data.ps(1).ver_axis);

    % make structure for plotting options
    % general plooting options
    data.psv_options.plot.bin.equidistant = 0;
    data.psv_options.plot.bin.nbins = 51;
    data.psv_options.plot.bin.equalnum = 1;
    data.psv_options.plot.bin.nparts = 1000;
    data.psv_options.plot.bin.manstep = 0;
    data.psv_options.plot.bin.stepsize = 1e-5;
    data.psv_options.plot.bin.man_g_sigma = 0;
    data.psv_options.plot.bin.g_sigma = 1e-5;
    data.psv_options.plot.p_frac = 1;

    % for the summary plot
    data.psv_options.plot.SumPlot.center_peak = 0;
    data.psv_options.plot.SumPlot.s_window_width = 3;
    data.psv_options.plot.SumPlot.sl_e_lim = 2e-6;
    data.psv_options.plot.SumPlot.betab_lim = 5;

    % Ming Chi
    data.psv_options.plot.MeshPlot.MingChi.yn      = 0;
    data.psv_options.plot.MeshPlot.MingChi.E0      = 20.;
    data.psv_options.plot.MeshPlot.MingChi.K       = 4.;
    data.psv_options.plot.MeshPlot.MingChi.beta    = 35.;
    data.psv_options.plot.MeshPlot.MingChi.lamu    = 0.037;
    % misc. plots
    data.psv_options.plot.make_meshplot = 0;
    data.psv_options.plot.make_sumplot = 0;
    data.psv_options.plot.subtractDispersion = 0;
    if (strcmp(get(handles.Options_Sub_Disp,'Check'),'on'));
        data.psv_options.plot.subtractDispersion = 1;
    end
    % double structure
    data.psv_options(2) = data.psv_options(1);
    psv_message(data, 'Initializing done',1);
end

function [popupString1 popupString2 ] = getPopupEntries(data, index, sliceable)
    popupString1 = {'hor';'p_hor';'ver';'p_ver';'long';'de/e';'I'};
    popupString2 = {'hor';'p_hor';'ver';'p_ver';'long';'de/e'};
    % offer different functionality of vertical axis depending on horizontal
    % axis setting
    % if hor_axis = longitudinal
    if (data.ps(index).hor_axis == 5 && ~sliceable)
        if hasField(data, index)
            popupString1 = {'hor';'p_hor';'ver';'p_ver';'long';'de/e'; ...
                'I';'e_hor';'e_ver';'dE/E'; 'E_long';'E_trans'};
        else
            popupString1 = {'hor';'p_hor';'ver';'p_ver';'long';'de/e'; ...
                'I';'e_hor';'e_ver';'dE/E'};
        end
    elseif (data.ps(index).hor_axis == 7)
%        popupString1 = {'hor_RMS';'p_hor_RMS';'ver_RMS';'p_ver_RMS'; ...
%                        'long_RMS';'p_long_RMS'; 'hor_emit';'ver_emit';...
%                        'long_emit'; 'hor_beta';'ver_beta';'long_beta'};
        popupString1 = {'Bunch Length [m]'; 'Energy Spread [rel.]'; ...
                        'Horizontal Beta Fkt. [m]'; ...
                        'Horizontal Emittance [m]'; ...
                        'Hor. Slice Emitt. (center) [m]'; ...
                        'Peak current [A]'};
    end
    
    if (isfield(data.ps,'mesh_data')) 
        if (size(data.ps(index).mesh_data) > 1)
            popupString2 = {'hor';'p_hor';'ver';'p_ver';'long';'de/e';'mesh'};
        end
    end
end

function result=isSliceable(data, index)
    result = false;
    if (isfield(data.ps(index), 'nbins'))
        if (~ isempty(data.ps(index).nbins))&&(data.ps(index).nbins > 1)
            result = true;
        end
    end    
end

function result = hasField(data, index)
    result = false;
    if (isfield(data.ps(index), 'fields')) && (~ isempty(data.ps(index).fields))
        result = true;
    end
end