function B = psv_smooth_I(A,M,sigma,q0,v)
% hands back a smoothed current or charge distribution
%   A       : position array
%   M       : number of particles for position smoothing
%   sigma   : sigma of gaussian used for gaussian smoothing
%   q0      : total charge
%   v       : bunch velocity (1 hands back a charge distribution, 3e8 a
%             current distribution)
%
% TL, 3_2006

A = psv_equal_s(A,M);
%
N_sigma=3;
a = min(A)-N_sigma*sigma;
b = max(A)+N_sigma*sigma;
s = 0.25*sigma;
N = ceil((b-a)/s);
s = (b-a)/N;
%
%--- pre-set arrays
B=zeros(N,2);
C=zeros(N,1);
for n=1:N
    B(n,1)  = a + n*s;
%    B(n,2)  = 0;
%    C(n)    = 0;
end
%
for k=1:length(A)-1
    c = (A(k)-a)/s;
    i = floor(c);
    xi = 1 + i - c;
    C(i) = C(i) + xi;
    C(i+1) = C(i+1) + (1-xi);
end
%
K = floor(N_sigma*sigma/s + 0.5);
G(1) = 1;
su = 1;
for k=2:K
    G(k) = exp(-0.5*(k*s/sigma)^2);
    su = su + G(k)*2;
end
G = G/su;
%

for n = K:N-K
    for i = -(K-1):K-1
        if(i==0)
            B(n-i,2) = B(n-i,2) + C(n)*1;
        else
            B(n-i,2) = B(n-i,2) + C(n)*G(abs(i));
        end
    end
end
%
S = sum(B(:,2));
B(:,2) = B(:,2)*(q0*v/(S*s));
%
%
%--------------------------------------------------------------------------
function y = psv_equal_s(A,M)
% array position smoothing by averaging
%   A       : position array
%   M       : number of particles for position smoothing
% TL 3_2006
N = length(A)-1;
x = sort(A);
%
% Stammsummen
s = cumsum(x);
s=[0 ; s];
% equalize
y=zeros(length(s),1);
for n=2:N-1
    m = floor(0.5*min([M N-n n-1]));
    y(n) = (s(n+m-1) - s(n-m))/(2*m +1);
end 